==> cms-db_v0.7.5.tar.gz: admin/adminsettings.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('root');
include('locale.inc.php');
$locale = new LocalizingClass('adminsettings');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('title') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css" />
		<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'anchormenu-mobile.css' : 'anchormenu.css'; ?>" />
		<script type="text/javascript">
		/* <![CDATA[ */
		function previewColors() {
			bg_r = document.getElementsByName("bg_r")[0].value
				if (bg_r > 255) { document.getElementsByName("bg_r")[0].value = 255 }
				if (isNaN(bg_r)) { document.getElementsByName("bg_r")[0].value = "" }
			bg_g = document.getElementsByName("bg_g")[0].value
				if (bg_g > 255) { document.getElementsByName("bg_g")[0].value = 255 }
				if (isNaN(bg_g)) { document.getElementsByName("bg_g")[0].value = "" }
			bg_b = document.getElementsByName("bg_b")[0].value
				if (bg_b > 255) { document.getElementsByName("bg_b")[0].value = 255 }
				if (isNaN(bg_b)) { document.getElementsByName("bg_b")[0].value = "" }
			document.getElementById("bg").style.background = "rgb("+bg_r+","+bg_g+","+bg_b+")"
			
			text_r = document.getElementsByName("text_r")[0].value
				if (text_r > 255) { document.getElementsByName("text_r")[0].value = 255 }
				if (isNaN(text_r)) { document.getElementsByName("text_r")[0].value = "" }
			text_g = document.getElementsByName("text_g")[0].value
				if (text_g > 255) { document.getElementsByName("text_g")[0].value = 255 }
				if (isNaN(text_g)) { document.getElementsByName("text_g")[0].value = "" }
			text_b = document.getElementsByName("text_b")[0].value
				if (text_b > 255) { document.getElementsByName("text_b")[0].value = 255 }
				if (isNaN(text_b)) { document.getElementsByName("text_b")[0].value = "" }
			document.getElementById("text").style.background = "rgb("+text_r+","+text_g+","+text_b+")"
		}
		function setColors(bg_r,bg_g,bg_b,text_r,text_g,text_b) {
			document.getElementsByName("bg_r")[0].value = bg_r
			document.getElementsByName("bg_g")[0].value = bg_g
			document.getElementsByName("bg_b")[0].value = bg_b
			document.getElementsByName("text_r")[0].value = text_r
			document.getElementsByName("text_g")[0].value = text_g
			document.getElementsByName("text_b")[0].value = text_b
			previewColors()
		}
		/*]]>*/
		</script>
	</head>
	<body>

		<h1><?php locale('desc_settings') ?></h1>

		<div class="anchormenu"><span class="leftcorner">&nbsp;</span><ul><li><a href="users.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_usersettings') ?></a></li><li><a href="commonsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_commonsettings') ?></a></li><li><a href="url.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_urlsettings') ?></a></li><li><a href="adminsettings.php?<?php echo SID ?>" class="nonewtab active"><?php locale('link_adminsettings') ?></a></li><li><a href="locale.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_localesettings') ?></a></li></ul><span class="rightcorner">&nbsp;</span></div>

		<?php
		if (isset($_POST['button'])) {
			$writethis = '<?php
			$bg_r = "'.$_POST["bg_r"].'";
			$bg_g = "'.$_POST["bg_g"].'";
			$bg_b = "'.$_POST["bg_b"].'";
			$text_r = "'.$_POST["text_r"].'";
			$text_g = "'.$_POST["text_g"].'";
			$text_b = "'.$_POST["text_b"].'";
			$view = "'.$_POST["view"].'";
			?>';
			$datei = fopen('../data/settings/admin.inc.php','w+');
			fwrite($datei,$writethis);
			fclose($datei);
			echo '<p class="hint">'.locale('desc_settings-saved',true).'<br /><em>'.locale('desc_reload',true).'</em></p>';
		}
		include("../data/settings/admin.inc.php");
		?>

		<h2><?php locale('title') ?></h2>
		<form action="adminsettings.php?<?php echo SID ?>" method="post">
				<fieldset>
					<legend><?php locale('title_view') ?></legend>
					<input type="radio" name="view" id="icons" value="icons" <?php if ($view == 'icons') { echo 'checked="checked"'; }?> />
					<label for="icons"><?php locale('desc_view-icons') ?></label><br />
					<input type="radio" name="view" id="menu" value="menu" <?php if ($view == 'menu') { echo 'checked="checked"'; }?> />
					<label for="menu"><?php locale('desc_view-menu') ?></label>
				</fieldset>
				<fieldset>
					<legend><?php locale('title_colors') ?></legend>
						<p><?php locale('desc_colors') ?></p>
						<p>
							<?php locale('desc_color-background') ?>: <span style="position:absolute;left:150px">rgb(
							<input style="background-color:rgb(255,0,0);color:rgb(255,255,255);font-weight:bold;border:1px solid #cccccc" onkeyup="previewColors()" type="text" name="bg_r" maxlength="3" size="3" value="<?php echo $bg_r ?>" />,
							<input style="background-color:rgb(0,255,0);color:rgb(255,255,255);font-weight:bold;border:1px solid #cccccc" onkeyup="previewColors()" type="text" name="bg_g" maxlength="3" size="3" value="<?php echo $bg_g ?>" />,
							<input style="background-color:rgb(0,0,255);color:rgb(255,255,255);font-weight:bold;border:1px solid #cccccc" onkeyup="previewColors()" type="text" name="bg_b" maxlength="3" size="3" value="<?php echo $bg_b ?>" />)
							<span id="bg" style="background:rgb(<?php echo $bg_r ?>,<?php echo $bg_g ?>,<?php echo $bg_b ?>);border:1px solid #cccccc">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span></span><br />
							<?php locale('desc_color-text') ?>: <span style="position:absolute;left:150px">rgb(
							<input style="background-color:rgb(255,0,0);color:rgb(255,255,255);font-weight:bold;border:1px solid #cccccc" onkeyup="previewColors()" type="text" name="text_r" maxlength="3" size="3" value="<?php echo $text_r ?>" />,
							<input style="background-color:rgb(0,255,0);color:rgb(255,255,255);font-weight:bold;border:1px solid #cccccc" onkeyup="previewColors()" type="text" name="text_g" maxlength="3" size="3" value="<?php echo $text_g ?>" />,
							<input style="background-color:rgb(0,0,255);color:rgb(255,255,255);font-weight:bold;border:1px solid #cccccc" onkeyup="previewColors()" type="text" name="text_b" maxlength="3" size="3" value="<?php echo $text_b ?>" />)
							<span id="text" style="background:rgb(<?php echo $text_r ?>,<?php echo $text_g ?>,<?php echo $text_b ?>);border:1px solid #cccccc">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
						</span>
					</p>
					<p>
					<?php locale('desc_suggestions') ?>:
					<a href="javascript:setColors(0,0,255,255,255,255)" style="background:rgb(0,0,255); color:rgb(255,255,255); border:1px solid #cccccc; margin-left:5px">&nbsp;Text&nbsp;</a>
					<a href="javascript:setColors(50,100,255,255,255,255)" style="background:rgb(50,100,255); color:rgb(255,255,255); border:1px solid #cccccc; margin-left:5px">&nbsp;Text&nbsp;</a>
					<a href="javascript:setColors(0,150,255,255,255,255)" style="background:rgb(0,150,255); color:rgb(255,255,255); border:1px solid #cccccc; margin-left:5px">&nbsp;Text&nbsp;</a>
					<a href="javascript:setColors(235,205,145,0,0,0)" style="background:rgb(235,205,145); color:rgb(0,0,0); border:1px solid #cccccc; margin-left:5px">&nbsp;Text&nbsp;</a>
					<a href="javascript:setColors(50,200,50,255,255,255)" style="background:rgb(50,200,50); color:rgb(255,255,255); border:1px solid #cccccc; margin-left:5px">&nbsp;Text&nbsp;</a>
					<a href="javascript:setColors(255,255,0,0,0,0)" style="background:rgb(255,255,0); color:rgb(0,0,0); border:1px solid #cccccc; margin-left:5px">&nbsp;Text&nbsp;</a>
					<a href="javascript:setColors(255,100,0,255,255,255)" style="background:rgb(255,100,0); color:rgb(255,255,255); border:1px solid #cccccc; margin-left:5px">&nbsp;Text&nbsp;</a>
					<a href="javascript:setColors(0,0,0,255,255,255)" style="background:rgb(0,0,0); color:rgb(255,255,255); border:1px solid #cccccc; margin-left:5px">&nbsp;Text&nbsp;</a>
					<a href="javascript:setColors(255,255,255,0,0,0)" style="background:rgb(255,255,255); color:rgb(0,0,0); border:1px solid #cccccc; margin-left:5px">&nbsp;Text&nbsp;</a>
					</p>
				</fieldset>
				<p>
					<input type="submit" name="button" value="<?php locale('button_save') ?>" />
				</p>
		</form>

	</body>
</html>

==> cms-db_v0.7.9.tar.gz: admin/adminsettings.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('root');
include('locale.inc.php');
$locale = new LocalizingClass('adminsettings');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('title') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css" />
		<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'style-extra-mobile.css' : 'style-extra.css'; ?>" />
		<script type="text/javascript">
		/* <![CDATA[ */
		function previewColors() {
			bg_r = document.getElementsByName("bg_r")[0].value
				if (bg_r > 255) { document.getElementsByName("bg_r")[0].value = 255 }
				if (isNaN(bg_r)) { document.getElementsByName("bg_r")[0].value = "" }
			bg_g = document.getElementsByName("bg_g")[0].value
				if (bg_g > 255) { document.getElementsByName("bg_g")[0].value = 255 }
				if (isNaN(bg_g)) { document.getElementsByName("bg_g")[0].value = "" }
			bg_b = document.getElementsByName("bg_b")[0].value
				if (bg_b > 255) { document.getElementsByName("bg_b")[0].value = 255 }
				if (isNaN(bg_b)) { document.getElementsByName("bg_b")[0].value = "" }
			document.getElementById("bg").style.background = "rgb("+bg_r+","+bg_g+","+bg_b+")"
			
			text_r = document.getElementsByName("text_r")[0].value
				if (text_r > 255) { document.getElementsByName("text_r")[0].value = 255 }
				if (isNaN(text_r)) { document.getElementsByName("text_r")[0].value = "" }
			text_g = document.getElementsByName("text_g")[0].value
				if (text_g > 255) { document.getElementsByName("text_g")[0].value = 255 }
				if (isNaN(text_g)) { document.getElementsByName("text_g")[0].value = "" }
			text_b = document.getElementsByName("text_b")[0].value
				if (text_b > 255) { document.getElementsByName("text_b")[0].value = 255 }
				if (isNaN(text_b)) { document.getElementsByName("text_b")[0].value = "" }
			document.getElementById("text").style.background = "rgb("+text_r+","+text_g+","+text_b+")"
		}
		function setColors(bg_r,bg_g,bg_b,text_r,text_g,text_b) {
			document.getElementsByName("bg_r")[0].value = bg_r
			document.getElementsByName("bg_g")[0].value = bg_g
			document.getElementsByName("bg_b")[0].value = bg_b
			document.getElementsByName("text_r")[0].value = text_r
			document.getElementsByName("text_g")[0].value = text_g
			document.getElementsByName("text_b")[0].value = text_b
			previewColors()
		}
		/*]]>*/
		</script>
	</head>
	<body>

		<h1><?php locale('desc_settings') ?></h1>

		<div class="anchormenu"><span class="leftcorner">&nbsp;</span><ul><li><a href="users.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_usersettings') ?></a></li><li><a href="commonsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_commonsettings') ?></a></li><li><a href="url.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_urlsettings') ?></a></li><li><a href="adminsettings.php?<?php echo SID ?>" class="nonewtab active"><?php locale('link_adminsettings') ?></a></li><li><a href="locale.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_localesettings') ?></a></li></ul><span class="rightcorner">&nbsp;</span></div>

		<?php
		if (isset($_POST['button'])) {
			$writethis = '<?php
			$bg_r = "'.$_POST["bg_r"].'";
			$bg_g = "'.$_POST["bg_g"].'";
			$bg_b = "'.$_POST["bg_b"].'";
			$text_r = "'.$_POST["text_r"].'";
			$text_g = "'.$_POST["text_g"].'";
			$text_b = "'.$_POST["text_b"].'";
			$view = "'.$_POST["view"].'";
			?>';
			$datei = fopen('../data/settings/admin.inc.php','w+');
			fwrite($datei,$writethis);
			fclose($datei);
			echo '<p class="hint">'.locale('desc_settings-saved',true).'<br /><em>'.locale('desc_reload',true).'</em></p>';
		}
		include("../data/settings/admin.inc.php");
		?>

		<h2><?php locale('title') ?></h2>
		<form action="adminsettings.php?<?php echo SID ?>" method="post">
				<fieldset>
					<legend><?php locale('title_view') ?></legend>
					<input type="radio" name="view" id="icons" value="icons" <?php if ($view == 'icons') { echo 'checked="checked"'; }?> />
					<label for="icons"><?php locale('desc_view-icons') ?></label><br />
					<input type="radio" name="view" id="menu" value="menu" <?php if ($view == 'menu') { echo 'checked="checked"'; }?> />
					<label for="menu"><?php locale('desc_view-menu') ?></label>
				</fieldset>
				<fieldset>
					<legend><?php locale('title_colors') ?></legend>
						<p><?php locale('desc_colors') ?></p>
						<p>
							<?php locale('desc_color-background') ?>: <span style="position:absolute;left:150px">rgb(
							<input style="background-color:rgb(255,0,0);color:rgb(255,255,255);font-weight:bold;border:1px solid #cccccc" onkeyup="previewColors()" type="text" name="bg_r" maxlength="3" size="3" value="<?php echo $bg_r ?>" />,
							<input style="background-color:rgb(0,255,0);color:rgb(255,255,255);font-weight:bold;border:1px solid #cccccc" onkeyup="previewColors()" type="text" name="bg_g" maxlength="3" size="3" value="<?php echo $bg_g ?>" />,
							<input style="background-color:rgb(0,0,255);color:rgb(255,255,255);font-weight:bold;border:1px solid #cccccc" onkeyup="previewColors()" type="text" name="bg_b" maxlength="3" size="3" value="<?php echo $bg_b ?>" />)
							<span id="bg" style="background:rgb(<?php echo $bg_r ?>,<?php echo $bg_g ?>,<?php echo $bg_b ?>);border:1px solid #cccccc">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span></span><br />
							<?php locale('desc_color-text') ?>: <span style="position:absolute;left:150px">rgb(
							<input style="background-color:rgb(255,0,0);color:rgb(255,255,255);font-weight:bold;border:1px solid #cccccc" onkeyup="previewColors()" type="text" name="text_r" maxlength="3" size="3" value="<?php echo $text_r ?>" />,
							<input style="background-color:rgb(0,255,0);color:rgb(255,255,255);font-weight:bold;border:1px solid #cccccc" onkeyup="previewColors()" type="text" name="text_g" maxlength="3" size="3" value="<?php echo $text_g ?>" />,
							<input style="background-color:rgb(0,0,255);color:rgb(255,255,255);font-weight:bold;border:1px solid #cccccc" onkeyup="previewColors()" type="text" name="text_b" maxlength="3" size="3" value="<?php echo $text_b ?>" />)
							<span id="text" style="background:rgb(<?php echo $text_r ?>,<?php echo $text_g ?>,<?php echo $text_b ?>);border:1px solid #cccccc">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>
						</span>
					</p>
					<p>
					<?php locale('desc_suggestions') ?>:
					<a href="javascript:setColors(0,0,255,255,255,255)" style="background:rgb(0,0,255); color:rgb(255,255,255); border:1px solid #cccccc; margin-left:5px">&nbsp;Text&nbsp;</a>
					<a href="javascript:setColors(50,100,255,255,255,255)" style="background:rgb(50,100,255); color:rgb(255,255,255); border:1px solid #cccccc; margin-left:5px">&nbsp;Text&nbsp;</a>
					<a href="javascript:setColors(0,150,255,255,255,255)" style="background:rgb(0,150,255); color:rgb(255,255,255); border:1px solid #cccccc; margin-left:5px">&nbsp;Text&nbsp;</a>
					<a href="javascript:setColors(235,205,145,0,0,0)" style="background:rgb(235,205,145); color:rgb(0,0,0); border:1px solid #cccccc; margin-left:5px">&nbsp;Text&nbsp;</a>
					<a href="javascript:setColors(50,200,50,255,255,255)" style="background:rgb(50,200,50); color:rgb(255,255,255); border:1px solid #cccccc; margin-left:5px">&nbsp;Text&nbsp;</a>
					<a href="javascript:setColors(255,255,0,0,0,0)" style="background:rgb(255,255,0); color:rgb(0,0,0); border:1px solid #cccccc; margin-left:5px">&nbsp;Text&nbsp;</a>
					<a href="javascript:setColors(255,100,0,255,255,255)" style="background:rgb(255,100,0); color:rgb(255,255,255); border:1px solid #cccccc; margin-left:5px">&nbsp;Text&nbsp;</a>
					<a href="javascript:setColors(0,0,0,255,255,255)" style="background:rgb(0,0,0); color:rgb(255,255,255); border:1px solid #cccccc; margin-left:5px">&nbsp;Text&nbsp;</a>
					<a href="javascript:setColors(255,255,255,0,0,0)" style="background:rgb(255,255,255); color:rgb(0,0,0); border:1px solid #cccccc; margin-left:5px">&nbsp;Text&nbsp;</a>
					</p>
				</fieldset>
				<p>
					<input type="submit" name="button" value="<?php locale('button_save') ?>" />
				</p>
		</form>

	</body>
</html>
